From de43e24c63556a38f11fb7786c35783c010e9618 Mon Sep 17 00:00:00 2001
From: MarkAckert
Date: Wed, 27 Nov 2024 11:32:38 -0500
Subject: [PATCH 1/8] adds python sdk to sourceDependencies. adds new field
"core" to source dep entry
Signed-off-by: MarkAckert
---
manifest.json.template | 10 +++++++++-
1 file changed, 9 insertions(+), 1 deletion(-)
diff --git a/manifest.json.template b/manifest.json.template
index be11c98858..c75c0588ed 100644
--- a/manifest.json.template
+++ b/manifest.json.template
@@ -137,7 +137,7 @@
"version": "~2.0.0-SNAPSHOT"
},
"org.zowe.licenses": {
- "version": "2.3.0",
+ "version": "3.0.0",
"artifact": "zowe_licenses_full.zip"
}
},
@@ -391,6 +391,14 @@
"tag": "v2.x/master",
"destinations": ["Zowe PAX"]
}]
+ }, {
+ "componentGroup": "Zowe Client Python SDK",
+ "entries": [{
+ "repository": "zowe-client-python-sdk",
+ "core": false,
+ "tag": "main",
+ "destinations": ["Zowe Client Python SDK"]
+ }]
}
],
"imageDependencies": {
From c539e099dc0696546bcd5ca1080034b7d6c1ec50 Mon Sep 17 00:00:00 2001
From: MarkAckert
Date: Mon, 9 Dec 2024 16:28:39 -0500
Subject: [PATCH 2/8] adjust licenses version after cherry-pick
Signed-off-by: MarkAckert
---
manifest.json.template | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/manifest.json.template b/manifest.json.template
index c75c0588ed..89c2eb6aab 100644
--- a/manifest.json.template
+++ b/manifest.json.template
@@ -137,7 +137,7 @@
"version": "~2.0.0-SNAPSHOT"
},
"org.zowe.licenses": {
- "version": "3.0.0",
+ "version": "2.18.0",
"artifact": "zowe_licenses_full.zip"
}
},
From d2873eb745c0ffc282186023197af3a74dcbe01a Mon Sep 17 00:00:00 2001
From: Mark Ackert <35308966+MarkAckert@users.noreply.github.com>
Date: Wed, 4 Dec 2024 14:24:09 -0500
Subject: [PATCH 3/8] Merge cherry-pick PR #4092 into v2
Signed-off-by: MarkAckert
---
.github/scripts/cicd_test/make_matrix.sh | 5 ---
.github/workflows/cicd-test-readme.md | 5 +--
.github/workflows/cicd-test.yml | 9 +---
.pax/pre-packaging.sh | 7 +--
bin/libs/node.sh | 2 +-
bin/libs/node.ts | 2 +-
.../extended/node-versions/node-v18.ts | 45 -------------------
7 files changed, 10 insertions(+), 65 deletions(-)
delete mode 100644 tests/installation/src/__tests__/extended/node-versions/node-v18.ts
diff --git a/.github/scripts/cicd_test/make_matrix.sh b/.github/scripts/cicd_test/make_matrix.sh
index 81273471ab..0af3d8cd77 100644
--- a/.github/scripts/cicd_test/make_matrix.sh
+++ b/.github/scripts/cicd_test/make_matrix.sh
@@ -32,11 +32,6 @@ case $install_test_choice in
test_file="$KEYRING_TESTFILE"
;;
-"z/OS node v18")
- test_file="$ZOS_NODE_V18_TESTFILE"
- test_force_system="zzow11"
- ;;
-
"z/OS node v20")
test_file="$ZOS_NODE_V20_TESTFILE"
;;
diff --git a/.github/workflows/cicd-test-readme.md b/.github/workflows/cicd-test-readme.md
index e1b081a2e5..7e4b80d984 100644
--- a/.github/workflows/cicd-test-readme.md
+++ b/.github/workflows/cicd-test-readme.md
@@ -29,7 +29,7 @@ Workflow trigger is at [cicd-test](https://github.com/zowe/zowe-install-packagin
- SMPE PTF
- Extensions
- Keyring
- - z/OS node v18
+ - z/OS node v20
- Non-strict Verify External Certificate
- Install PTF twice
- VSAM Caching storage method
@@ -109,7 +109,7 @@ Background: CICD testing relies on a `zowe.pax` or `zowe-smpe.zip` (for SMPE ins
When running CICD integration tests during RC stage, the following string will be parsed into the Github Actions matrix. As a result, a total of 21 independent jobs will be spawned.
```
-basic/install.ts(zzow09,zzow10,zzow11);basic/install-ptf.ts(zzow09,zzow10,zzow11);basic/install-ext.ts(zzow10);extended/keyring.ts(zzow09,zzow10,zzow11);extended/node-versions/node-v18.ts(zzow09,zzow10,zzow11);extended/node-versions/node-v20.ts(zzow09,zzow10,zzow11);extended/certificates/nonstrict-verify-external-certificate.ts(zzow09)
+basic/install.ts(zzow09,zzow10,zzow11);basic/install-ptf.ts(zzow09,zzow10,zzow11);basic/install-ext.ts(zzow10);extended/keyring.ts(zzow09,zzow10,zzow11);extended/node-versions/node-v20.ts(zzow09,zzow10,zzow11);extended/node-versions/node-v20.ts(zzow09,zzow10,zzow11);extended/certificates/nonstrict-verify-external-certificate.ts(zzow09)
```
Total elapsed time when running in parallel is approximately 3.5 hours on paper idealy if all parallel jobs are executing at the same time. In reality, from numerous tests performed, total elapsed time is around 4 hours.
@@ -121,7 +121,6 @@ Selected test running elapsed time:
| ---- | ------------ |
| Convenience Pax | 53m |
| SMPE PTF | 68m |
-| z/OS node v18 | 45m |
| z/OS node v20 | 45m |
| Keyring | 53m |
| Non-strict Verify External Certificate | 51m |
diff --git a/.github/workflows/cicd-test.yml b/.github/workflows/cicd-test.yml
index ca6ee6e670..91ce831b9a 100644
--- a/.github/workflows/cicd-test.yml
+++ b/.github/workflows/cicd-test.yml
@@ -31,7 +31,6 @@ on:
- SMPE PTF
- Extensions
- Keyring
- - z/OS node v18
- z/OS node v20
- Non-strict Verify External Certificate
- Install PTF Twice
@@ -69,8 +68,8 @@ env:
DEFAULT_ZOWE_EXT_ARTIFACTORY_PATTERN: libs-snapshot-local/org/zowe/{ext-name}/*/{ext-name}-*.pax
# below block can be overwritten, adjusted by DevOps only
- # ZOS_NODE_VERSION more to choose from: v16.20.1, v18.16.0
- ZOS_NODE_VERSION: v16.20.1
+ # ZOS_NODE_VERSION more to choose from: v18.16.0, v20.11.0
+ ZOS_NODE_VERSION: v18.16.0
CLIENT_NODE_VERSION: v12.18.3
INSTALL_TEST_DEBUG_INFORMATION: zowe-install-test:*
SANITY_TEST_DEBUG_INFORMATION: zowe-sanity-test:*
@@ -81,7 +80,6 @@ env:
SMPE_PTF_TESTFILE: basic/install-ptf.ts
EXTENSIONS_TESTFILE: basic/install-ext.ts
KEYRING_TESTFILE: extended/keyring.ts
- ZOS_NODE_V18_TESTFILE: extended/node-versions/node-v18.ts
ZOS_NODE_V20_TESTFILE: extended/node-versions/node-v20.ts
NON_STRICT_VERIFY_EXTERNAL_CERTIFICATE_TESTFILE: extended/certificates/nonstrict-verify-external-certificate.ts
INSTALL_PTF_TWICE_TESTFILE: extended/install-ptf-two-times.ts
@@ -298,9 +296,6 @@ jobs:
case 'Keyring':
eta = 53
break;
- case 'z/OS node v18':
- eta = 45
- break;
case 'z/OS node v20':
eta = 45
break;
diff --git a/bin/libs/node.sh b/bin/libs/node.sh
index d457c76b2f..4782864d7d 100644
--- a/bin/libs/node.sh
+++ b/bin/libs/node.sh
@@ -22,7 +22,7 @@ export NODE_STDIN_CCSID=1047
# Workaround Fix for node 8.16.1 that requires compatibility mode for untagged files
export __UNTAGGED_READ_MODE=V6
-NODE_MIN=16
+NODE_MIN=18
ensure_node_is_on_path() {
if [[ ":${PATH}:" != *":${NODE_HOME}/bin:"* ]]; then
diff --git a/bin/libs/node.ts b/bin/libs/node.ts
index 3b20ccfd76..40880f5665 100644
--- a/bin/libs/node.ts
+++ b/bin/libs/node.ts
@@ -18,7 +18,7 @@ import * as shell from './shell';
import * as config from './config';
import { PathAPI as pathoid } from './pathoid';
-const NODE_MIN_VERSION=16;
+const NODE_MIN_VERSION=18;
// enforce encoding of stdio/stdout/stderr
// sometimes /dev/tty* ($SSH_TTY) are not configured properly, for example tagged as binary or wrong encoding
diff --git a/tests/installation/src/__tests__/extended/node-versions/node-v18.ts b/tests/installation/src/__tests__/extended/node-versions/node-v18.ts
deleted file mode 100644
index d6345a1df6..0000000000
--- a/tests/installation/src/__tests__/extended/node-versions/node-v18.ts
+++ /dev/null
@@ -1,45 +0,0 @@
-/**
- * This program and the accompanying materials are made available under the terms of the
- * Eclipse Public License v2.0 which accompanies this distribution, and is available at
- * https://www.eclipse.org/legal/epl-v20.html
- *
- * SPDX-License-Identifier: EPL-2.0
- *
- * Copyright IBM Corporation 2022
- */
-
-import {
- checkMandatoryEnvironmentVariables,
- installAndVerifyConvenienceBuild,
- showZoweRuntimeLogs,
-} from '../../../utils';
-import { TEST_TIMEOUT_CONVENIENCE_BUILD } from '../../../constants';
-
-// Only runs on zzow11 at time of change (04.2023). See cicd-test.yml and make_matrix.sh.
-const testServer = process.env.TEST_SERVER;
-const testSuiteName = 'Test convenience build installation with node.js v18';
-describe(testSuiteName, () => {
- beforeAll(() => {
- // validate variables
- checkMandatoryEnvironmentVariables([
- 'ZOWE_BUILD_LOCAL',
- ]);
- });
-
- test('install and verify', async () => {
- await installAndVerifyConvenienceBuild(
- testSuiteName,
- testServer,
- {
- 'zowe_build_local': process.env['ZOWE_BUILD_LOCAL'],
- 'zowe_custom_for_test': 'true',
- 'zos_node_home': '/ZOWE/node/node-v18.16.0',
- 'zowe_lock_keystore': 'false',
- }
- );
- }, TEST_TIMEOUT_CONVENIENCE_BUILD);
-
- afterAll(async () => {
- await showZoweRuntimeLogs(testServer);
- })
-});
From ad00d5126b50c4cbd8c028023dc9a89f2912a7b5 Mon Sep 17 00:00:00 2001
From: MarkAckert
Date: Mon, 9 Dec 2024 16:21:13 -0500
Subject: [PATCH 4/8] add node-v22 tests and add them to extended suite
Signed-off-by: MarkAckert
---
.github/scripts/cicd_test/make_matrix.sh | 4 ++
.github/workflows/cicd-test.yml | 4 +-
.../extended/node-versions/node-v22.ts | 44 +++++++++++++++++++
3 files changed, 51 insertions(+), 1 deletion(-)
create mode 100644 tests/installation/src/__tests__/extended/node-versions/node-v22.ts
diff --git a/.github/scripts/cicd_test/make_matrix.sh b/.github/scripts/cicd_test/make_matrix.sh
index 0af3d8cd77..4aea7a10ae 100644
--- a/.github/scripts/cicd_test/make_matrix.sh
+++ b/.github/scripts/cicd_test/make_matrix.sh
@@ -36,6 +36,10 @@ case $install_test_choice in
test_file="$ZOS_NODE_V20_TESTFILE"
;;
+"z/OS node v22")
+ test_file="$ZOS_NODE_V22_TESTFILE"
+ ;;
+
"Non-strict Verify External Certificate")
test_file="$NON_STRICT_VERIFY_EXTERNAL_CERTIFICATE_TESTFILE"
;;
diff --git a/.github/workflows/cicd-test.yml b/.github/workflows/cicd-test.yml
index 91ce831b9a..1cf8977285 100644
--- a/.github/workflows/cicd-test.yml
+++ b/.github/workflows/cicd-test.yml
@@ -32,6 +32,7 @@ on:
- Extensions
- Keyring
- z/OS node v20
+ - z/OS node v22
- Non-strict Verify External Certificate
- Install PTF Twice
- VSAM Caching Storage Method
@@ -81,6 +82,7 @@ env:
EXTENSIONS_TESTFILE: basic/install-ext.ts
KEYRING_TESTFILE: extended/keyring.ts
ZOS_NODE_V20_TESTFILE: extended/node-versions/node-v20.ts
+ ZOS_NODE_V22_TESTFILE: extended/node-versions/node-v22.ts
NON_STRICT_VERIFY_EXTERNAL_CERTIFICATE_TESTFILE: extended/certificates/nonstrict-verify-external-certificate.ts
INSTALL_PTF_TWICE_TESTFILE: extended/install-ptf-two-times.ts
VSAM_CACHING_STORAGE_METHOD_TESTFILE: extended/caching-storages/vsam-storage.ts
@@ -88,7 +90,7 @@ env:
CONFIG_MANAGER_TESTFILE: extended/config-manager/enable-config-manager.ts
GENERAL_API_DOCUMENTATION_TESTFILE: basic/install-api-gen.ts
ZOWE_NIGHTLY_TESTS_FULL: basic/install.ts(all);basic/install-ptf.ts(all)
- ZOWE_RELEASE_TESTS_FULL: basic/install.ts(all);basic/install-ptf.ts(all);basic/install-ext.ts(any);extended/keyring.ts(all);extended/node-versions/node-v18.ts(zzow11);extended/node-versions/node-v20.ts(any);extended/certificates/nonstrict-verify-external-certificate.ts(any);extended/caching-storages/infinispan-storage.ts(any);extended/config-manager/enable-config-manager.ts(any)
+ ZOWE_RELEASE_TESTS_FULL: basic/install.ts(all);basic/install-ptf.ts(all);basic/install-ext.ts(any);extended/keyring.ts(all);extended/node-versions/node-v20.ts(any);extended/node-versions/node-v22.ts(any);extended/certificates/nonstrict-verify-external-certificate.ts(any);extended/caching-storages/infinispan-storage.ts(any);extended/config-manager/enable-config-manager.ts(any)
jobs:
display-dispatch-event-id:
diff --git a/tests/installation/src/__tests__/extended/node-versions/node-v22.ts b/tests/installation/src/__tests__/extended/node-versions/node-v22.ts
new file mode 100644
index 0000000000..8375055f01
--- /dev/null
+++ b/tests/installation/src/__tests__/extended/node-versions/node-v22.ts
@@ -0,0 +1,44 @@
+/**
+ * This program and the accompanying materials are made available under the terms of the
+ * Eclipse Public License v2.0 which accompanies this distribution, and is available at
+ * https://www.eclipse.org/legal/epl-v20.html
+ *
+ * SPDX-License-Identifier: EPL-2.0
+ *
+ * Copyright Zowe Contributors 2024
+ */
+
+import {
+ checkMandatoryEnvironmentVariables,
+ installAndVerifyConvenienceBuild,
+ showZoweRuntimeLogs,
+} from '../../../utils';
+import { TEST_TIMEOUT_CONVENIENCE_BUILD } from '../../../constants';
+
+const testServer = process.env.TEST_SERVER;
+const testSuiteName = 'Test convenience build installation with node.js v22';
+describe(testSuiteName, () => {
+ beforeAll(() => {
+ // validate variables
+ checkMandatoryEnvironmentVariables([
+ 'ZOWE_BUILD_LOCAL',
+ ]);
+ });
+
+ test('install and verify', async () => {
+ await installAndVerifyConvenienceBuild(
+ testSuiteName,
+ testServer,
+ {
+ 'zowe_build_local': process.env['ZOWE_BUILD_LOCAL'],
+ 'zowe_custom_for_test': 'true',
+ 'zos_node_home': '/ZOWE/node/node-v22.10.0',
+ 'zowe_lock_keystore': 'false',
+ }
+ );
+ }, TEST_TIMEOUT_CONVENIENCE_BUILD);
+
+ afterAll(async () => {
+ await showZoweRuntimeLogs(testServer);
+ })
+});
From 7491d3dd02fe6a0d091a7abd363b7a755a250af9 Mon Sep 17 00:00:00 2001
From: Mark Ackert <35308966+MarkAckert@users.noreply.github.com>
Date: Tue, 10 Dec 2024 13:51:50 -0500
Subject: [PATCH 5/8] Merge pull request #4104 from
zowe/user/markackert/dead-link-checker
Dead Link Checker
Signed-off-by: MarkAckert
---
.github/lychee.toml | 12 ++++++++
.github/workflows/link-check.yml | 49 ++++++++++++++++++++++++++++++++
workflows/files/ZWELOADC.xml | 8 +++---
3 files changed, 65 insertions(+), 4 deletions(-)
create mode 100644 .github/lychee.toml
create mode 100644 .github/workflows/link-check.yml
diff --git a/.github/lychee.toml b/.github/lychee.toml
new file mode 100644
index 0000000000..d256ce025a
--- /dev/null
+++ b/.github/lychee.toml
@@ -0,0 +1,12 @@
+# This lychee configuration tries to find dead links in zwe, pswi, and smpe files which may be displayed to the user.
+# This does not focus on dead links for internal-facing documentation, e.g. README.md.
+
+# We're including language sources as well as document files since the language sources embed URLs
+# which can be displayed to the user, e.g. 'zwe' shell script commands displaying help information.
+
+exclude_path = ['smpe/bld/service/_README_sample_sysmod_builds.docx']
+# This exclude list covers known urls which should be ignored, including ones which contained
+# templated values in typescript. The templates are covered by a wildcard.
+exclude = [ 'https://www.eclipse.org/legal/epl-v20.html', 'https://zowe.org/schemas/*', 'https://www.zowe.org/schemas/*', 'https://discovery', 'https://github.com/zowe/launcher/blob/*', 'https://myregistry/url$', 'https://your-zos-host-name/zosmf/*{1,60}', '^http://service.software.ibm.com/holdata/390holddata.html', ]
+
+hidden = true
diff --git a/.github/workflows/link-check.yml b/.github/workflows/link-check.yml
new file mode 100644
index 0000000000..d11b069c7a
--- /dev/null
+++ b/.github/workflows/link-check.yml
@@ -0,0 +1,49 @@
+# This link checker focuses on covering end-user facing links, not developer documentation.
+# This means we cover the smp/e, pswi, and zwe content.
+# The lychee toml files are set to ignore links which popped up in comments or variables.
+permissions: read-all
+
+name: Link Check CI
+
+on:
+ pull_request:
+ types: [opened, synchronize]
+ push:
+ branches:
+ - 'v3.x/staging'
+ - 'v2.x/staging'
+ workflow_dispatch:
+
+jobs:
+ lychee-link-check:
+ runs-on: ubuntu-latest
+
+ steps:
+ - uses: actions/checkout@11bd71901bbe5b1630ceea73d27597364c9af683 # v4.2.2
+
+ - name: Link Checker
+ id: lychee
+ uses: lycheeverse/lychee-action@f81112d0d2814ded911bd23e3beaa9dda9093915 # v2.1.0
+ with:
+ fail: true
+ format: json
+ output: lychee_output.json
+ args: --config ./.github/lychee.toml --no-progress --verbose --max-retries 10 'bin/**/*' 'smpe/**/*' 'workflows/**/*'
+
+ - name: Output failed links in console
+ id: quick-output
+ if: always()
+ run: |
+ if [[ -f "lychee_output.json" ]]; then
+ jq .fail_map lychee_output.json
+ else
+ echo "lychee command failed and didn't produce output"
+ fi
+
+ - name: Publish Output
+ id: publish
+ if: always()
+ uses: actions/upload-artifact@b4b15b8c7c6ac21ea08fcf65892d2ee8f75cf882
+ with:
+ name: lychee_results.json
+ path: lychee_output.json
diff --git a/workflows/files/ZWELOADC.xml b/workflows/files/ZWELOADC.xml
index c823b2b813..786e28fb37 100644
--- a/workflows/files/ZWELOADC.xml
+++ b/workflows/files/ZWELOADC.xml
@@ -192,7 +192,7 @@
Use this step to define the variables for RACF.
For more information about security system setup and it's variables, please open via right-click in new tab or window and refer to security documentation here
- configure RACF security certificates
+ configure RACF security certificates
or there RACDCERT ADD (Add certificate) command.
]]>
1
@@ -252,7 +252,7 @@
Use this step to define the variables for ACF2.
For more information about security system setup and it's variables, please open via right-click in new tab or window and refer to security documentation
- configure ACF2 security certificates.
+ configure ACF2 security certificates.
]]>
1
Security Administrator
@@ -367,7 +367,7 @@
This step will load signed client authentication certificate from the ${instance-output_dataset} into ESM
For more information about security system setup and it's variables, please open via right-click in new tab or window and refer to security documentation here
- configure RACF security certificates
+ configure RACF security certificates
or there RACDCERT ADD (Add certificate) command.
]]>
1
@@ -452,7 +452,7 @@ DCDSN(${instance-output_dataset}) TRUST
This step will load signed client authentication certificate from the ${instance-output_dataset} into ESM
For more information about security system setup and it's variables, please open via right-click in new tab or window and refer to security documentation
- configure ACF2 security certificates.
+ configure ACF2 security certificates.
]]>
1
Security Administrator
From 63d5d584ca87d0d6c6aa598c717f9619bf51ecb0 Mon Sep 17 00:00:00 2001
From: MarkAckert
Date: Tue, 10 Dec 2024 15:05:30 -0500
Subject: [PATCH 6/8] keep java8 for v2 pax build
Signed-off-by: MarkAckert
---
.pax/pre-packaging.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/.pax/pre-packaging.sh b/.pax/pre-packaging.sh
index 201b9aac03..dd95ee81f5 100755
--- a/.pax/pre-packaging.sh
+++ b/.pax/pre-packaging.sh
@@ -192,7 +192,7 @@ BASE_DIR=$(
# use node v18 to build
export NODE_HOME=/ZOWE/node/node-v18.16.0
-export JAVA_HOME=/ZOWE/node/J17.0_64
+export JAVA_HOME=/ZOWE/node/J8.0_64
export PATH=$JAVA_HOME/bin:$PATH
ZOWE_ROOT_DIR="${BASE_DIR}/content"
From 242f9a7df17263d0cb6af21a1c6e1d9bfc58a7d9 Mon Sep 17 00:00:00 2001
From: MarkAckert
Date: Tue, 10 Dec 2024 15:07:23 -0500
Subject: [PATCH 7/8] control JAVA_HOME in playbooks, rather than relying on
remote system profile
Signed-off-by: MarkAckert
---
playbooks/group_vars/marist.yml | 1 +
1 file changed, 1 insertion(+)
diff --git a/playbooks/group_vars/marist.yml b/playbooks/group_vars/marist.yml
index d6eed7dbfc..92ff54eb00 100644
--- a/playbooks/group_vars/marist.yml
+++ b/playbooks/group_vars/marist.yml
@@ -9,6 +9,7 @@ zowe_keystore_dir: /ZOWE/tmp/keystore
zowe_install_logs_dir: /ZOWE/tmp/logs
zowe_dataset_prefix: ZOWEAD3.ZWE
zowe_apiml_verify_certficates_of_services: false
+zos_java_home: /ZOWE/node/J8.0_64
# enable Non-Strict verify certificates by default
zowe_apiml_nonstrict_verify_certficates_of_services: true
zowe_jcllib: ZOWEAD3.ZWE.JCLLIB
From d0b528a1911904a12bef821637f4630881811c9e Mon Sep 17 00:00:00 2001
From: MarkAckert
Date: Thu, 12 Dec 2024 15:51:33 -0500
Subject: [PATCH 8/8] fix NODE_HOME_PATTERN
Signed-off-by: MarkAckert
---
.../cicd_test/prep7_more_test_prep/06_process_outputs.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/.github/scripts/cicd_test/prep7_more_test_prep/06_process_outputs.sh b/.github/scripts/cicd_test/prep7_more_test_prep/06_process_outputs.sh
index bce1d40594..89d12cf135 100644
--- a/.github/scripts/cicd_test/prep7_more_test_prep/06_process_outputs.sh
+++ b/.github/scripts/cicd_test/prep7_more_test_prep/06_process_outputs.sh
@@ -13,7 +13,7 @@
# Set outputs
echo ZOWE_ARTIFACTORY_FINAL=$ZOWE_ARTIFACTORY_FINAL >>$GITHUB_OUTPUT
echo ZOWE_ARTIFACTORY_FINAL_FILENAME=$ZOWE_ARTIFACTORY_FINAL_FILENAME >>$GITHUB_OUTPUT
-echo NODE_HOME_PATTERN=/ZOWE/node/node-$ZOS_NODE_VERSION-os390-s390x >>$GITHUB_OUTPUT
+echo NODE_HOME_PATTERN=/ZOWE/node/node-$ZOS_NODE_VERSION >>$GITHUB_OUTPUT
echo TEST_SERVER=$TEST_SERVER >>$GITHUB_OUTPUT
echo TEST_SERVER_NICKNAME=$TEST_SERVER_NICKNAME >>$GITHUB_OUTPUT
echo EXTENSION_LIST=$EXTENSION_LIST >>$GITHUB_OUTPUT
diff --git a/.pax/pre-packaging.sh b/.pax/pre-packaging.sh
index cb17b8244b..201b9aac03 100755
--- a/.pax/pre-packaging.sh
+++ b/.pax/pre-packaging.sh
@@ -190,9 +190,10 @@ BASE_DIR=$(
pwd
) # /.pax
-# use node v16 to build
-export NODE_HOME=/ZOWE/node/node-v16.20.1-os390-s390x
-
+# use node v18 to build
+export NODE_HOME=/ZOWE/node/node-v18.16.0
+export JAVA_HOME=/ZOWE/node/J17.0_64
+export PATH=$JAVA_HOME/bin:$PATH
ZOWE_ROOT_DIR="${BASE_DIR}/content"
cd "${BASE_DIR}"